@@ -9,7 +9,6 @@ EventChat = import_string('EVENT.chat.models')
 class ChatConsumer(WebsocketConsumer):
     def connect(self):
         self.event_id = self.scope['url_route']['kwargs']['event_id']
-        print(self.event_id)
         self.room_group_name = 'chat_%s' % self.event_id
 
         # Join room group
@@ -64,6 +63,22 @@ class ChatConsumer(WebsocketConsumer):
             Event_chat_queryset.state = 2
             Event_chat_queryset.save()
 
+        elif data['state'] == 5:  # 撤回
+            _id = text_data_json.get('id', None)
+            Event_chat_queryset = EventChat.objects.get(pk=_id)
+            Event_chat_queryset.state = 0
+            Event_chat_queryset.save()
+            send_data = {
+                'chat_id': _id,
+                'state': data['state']
+            }
+            async_to_sync(self.channel_layer.group_send)(
+                self.room_group_name,
+                {
+                    'type': 'event_chat_message',
+                    **send_data
+                }
+            )
     # Receive message from room group
 
     def event_chat_message(self, event):
