@@ -58,7 +58,7 @@ class CommentConsumer(WebsocketConsumer):
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
                 {
-                    'type': 'event_chat_message',
+                    'type': 'event_comment_message',
                     **data
                 }
             )
@@ -97,7 +97,7 @@ class CommentConsumer(WebsocketConsumer):
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
                 {
-                    'type': 'event_chat_message',
+                    'type': 'event_comment_message',
                     **send_data
                 }
             )
@@ -113,7 +113,7 @@ class CommentConsumer(WebsocketConsumer):
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
                 {
-                    'type': 'event_chat_message',
+                    'type': 'event_comment_message',
                     **send_data
                 }
             )
