@@ -4,9 +4,9 @@ from django.db import models
 class AbstractEventLivePPT(models.Model):
     event_id = models.IntegerField()
 
-    user_id = models.IntegerField()
-    unionid = models.CharField(max_length=32)
-    openid = models.CharField(max_length=32)
+    user_id = models.IntegerField(null=True)
+    unionid = models.CharField(max_length=32, null=True)
+    openid = models.CharField(max_length=32, null=True)
 
     nick_name = models.CharField(max_length=100)
     avatar_url = models.CharField(max_length=255)
@@ -22,5 +22,7 @@ class AbstractEventLivePPT(models.Model):
 
 
 class EventLivePPT(AbstractEventLivePPT):
+    image_list = models.JSONField(null=True)
+
     class Meta:
         db_table = 'event_live_ppt'
