@@ -88,10 +88,10 @@ class EventVoteUserView(CustomModelViewSet):
         return Response(response_data, status=status.HTTP_201_CREATED, headers=headers)
 
     def list(self, request, *args, **kwargs):
-        event_id = request.query_params.get('event_id', None)
+        schedule_id = request.query_params.get('schedule_id', None)
         openid = jwt_get_openid_handler(request.auth)
         data = self.model_class.objects.filter(
-            event_id=event_id, openid=openid).first()
+            schedule_id=schedule_id, openid=openid).first()
         if data:
             serializer = self.get_serializer(data)
             return Response({'code': '1', 'data': serializer.data})
