@@ -1,5 +1,4 @@
-import asyncio
-import websockets
+from django.http import HttpResponse
 from rest_framework.views import APIView
 from rest_framework.response import Response
 
@@ -19,7 +18,6 @@ class WeChatLoginView(APIView):
 
     def get(self, request, *args, **kwargs):
         scene_str = request.query_params.get('code', '')
-        scene_str = f'bluedot_pc_login_{scene_str}'
         result = OfficialAccount.qrcode.create({
             'expire_seconds': 86400,
             'action_name': 'QR_STR_SCENE',
@@ -31,21 +29,19 @@ class WeChatLoginView(APIView):
         return Response(result)
 
 
-async def send(uri, data):
-    async with websockets.connect(uri) as websocket:
-        await websocket.send(data)
-        await websocket.recv()
-
-
 class WeChatLoginWebSocketView(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
         scene_str = request.query_params.get('scene_str', '')
-        queryset = WeChatLogin.objects.filter(scene_str=scene_str).first()
-        if queryset and queryset.openid:
-            user_queryset = User.objects.filter(openid=queryset.openid).first()
-            token = jwt_create_token_wechat(
-                openid=user_queryset.openid, unionid=user_queryset.unionid, user_id=user_queryset.pk, wechat_id=user_queryset.wechat_id)
-            send(scene_str, {'token': token})
-            return Response()
+        openid = request.query_params.get('openid', '')
+        user_queryset = User.objects.filter(openid=openid).first()
+        token = jwt_create_token_wechat(openid=user_queryset.openid, unionid=user_queryset.unionid,
+                                        userid=user_queryset.pk, wechat_id=user_queryset.wechat_id)
+        return HttpResponse("""<script>
+var url = 'wss://cpa-global-wechat.bluewebonline.com/ws/wechat/login/""" + scene_str + """'
+var ws = new WebSocket(url);
+ws.onopen = function() {
+    ws.send(JSON.stringify({token:'"""+token+"""'}));
+};
+</script>""")
