@@ -89,7 +89,7 @@ class OAuth(APIView):
     def get(self, request, *args, **kwargs):
         redirect_uri = "http://" + request.get_host() + request.get_full_path()
         code = request.query_params.get('code', None)
-        referer_uri = request.query_params.get('referer_uri', None)
+        # referer_uri = request.query_params.get('referer_uri', None)
 
         if code:
             wechat_oauth = official_account_oauth(
@@ -122,10 +122,7 @@ class OAuth(APIView):
                 user_id = user_queryset.pk
             token = jwt_create_token_wechat(
                 openid=wechat_queryset.openid, unionid=wechat_queryset.unionid, userid=user_id, wechat_id=wechat_queryset.pk)
-            link_type = '?'
-            if "?" in referer_uri:
-                link_type = '&'
-            return HttpResponseRedirect(referer_uri + link_type + 'token=' + token)
+            return Response({'token': token})
         else:
             referer_uri = parse.quote(request.META['HTTP_REFERER'])
             link_type = '?'
